==> members-facade-1.0.2-20190110.063346-6-sources.jar: com/bizvane/members/facade/service/qywxapi/WxMembersApiService.java <==
package com.bizvane.members.facade.service.qywxapi;

import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.bizvane.members.facade.es.pojo.qywx.MembersFriendPojo;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.vo.qywx.MemberFriendsKeyQueryVo;
//import com.bizvane.members.facade.vo.qywx.MemberFriendsKeyQueryVo;
import com.bizvane.members.facade.vo.qywx.MembersFriendVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;

@FeignClient(value = "${feign.client.members.name}",path = "${feign.client.members.path}")
public interface WxMembersApiService {

	/**
	 * 更新会员备注
	 * 
	 * @param memberComment
	 * @param memberCode
	 * @return
	 */
	@RequestMapping(value = "/api/wxMembersApi/saveAndUpdateMembersComment", method = RequestMethod.POST)
	public ResponseData<Integer> saveAndUpdateMembersComment(@RequestParam("memberComment") String memberComment,
			@RequestParam("memberCode") String memberCode);

	/**
	 * 获取新会员列表
	 * 
	 * @param membersFriendVo
	 * @return
	 */
	@RequestMapping(value = "/api/wxMembersApi/getMembersList", method = RequestMethod.POST)
	public ResponseData<PageInfo<MembersFriendPojo>> getMembersList(@RequestBody MembersFriendVo membersFriendVo);

	/**
	 * 查询会员等级
	 * 
	 * @param brandId
	 * @return
	 */
	@RequestMapping(value = "/api/wxMembersApi/getLevelMap", method = RequestMethod.POST)
	public ResponseData<Map<Long, String>> getLevelMap(@RequestParam("brandId") Long brandId);

	@RequestMapping(value = "/api/wxMembersApi/updateMembersMark", method = RequestMethod.POST)
	public ResponseData<Integer> updateMembersMark(@RequestParam("mark") Integer mark,
			@RequestParam("memberCode") String memberCode);
	
	//根据条件查询会员信息
	@RequestMapping(value = "/api/wxMembersApi/getMemberFriendsWithMultiKeyWord", method = RequestMethod.POST)
	public ResponseData<MemberInfoModel> getMemberFriendsWithMultiKeyWord(
			@RequestBody MemberFriendsKeyQueryVo memberFriendsKeyQueryVo);

}

==> members-facade-1.0.2-20190129.032322-36-sources.jar: com/bizvane/members/facade/service/qywxapi/WxMembersApiService.java <==
package com.bizvane.members.facade.service.qywxapi;

import java.util.List;
import java.util.Map;

import com.bizvane.members.facade.vo.MemberInfoVo;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.bizvane.members.facade.es.pojo.qywx.MembersFriendPojo;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.vo.qywx.MemberFriendsKeyQueryVo;
//import com.bizvane.members.facade.vo.qywx.MemberFriendsKeyQueryVo;
import com.bizvane.members.facade.vo.qywx.MembersFriendVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;

@FeignClient(value = "${feign.client.members.name}",path = "${feign.client.members.path}")
public interface WxMembersApiService {

	/**
	 * 更新会员备注
	 * 
	 * @param memberComment
	 * @param memberCode
	 * @return
	 */
	@RequestMapping(value = "/api/wxMembersApi/saveAndUpdateMembersComment", method = RequestMethod.POST)
	public ResponseData<Integer> saveAndUpdateMembersComment(@RequestParam("memberComment") String memberComment,
			@RequestParam("memberCode") String memberCode);

	/**
	 * 获取新会员列表
	 * 
	 * @param membersFriendVo
	 * @return
	 */
	@RequestMapping(value = "/api/wxMembersApi/getMembersList", method = RequestMethod.POST)
	public ResponseData<PageInfo<MembersFriendPojo>> getMembersList(@RequestBody MembersFriendVo membersFriendVo);

	/**
	 * 查询会员等级
	 * 
	 * @param brandId
	 * @return
	 */
	@RequestMapping(value = "/api/wxMembersApi/getLevelMap", method = RequestMethod.POST)
	public ResponseData<Map<Long, String>> getLevelMap(@RequestParam("brandId") Long brandId);

	@RequestMapping(value = "/api/wxMembersApi/updateMembersMark", method = RequestMethod.POST)
	public ResponseData<Integer> updateMembersMark(@RequestParam("mark") Integer mark,
			@RequestParam("memberCode") String memberCode);
	
	//根据条件查询会员信息
	@RequestMapping(value = "/api/wxMembersApi/getMemberFriendsWithMultiKeyWord", method = RequestMethod.POST)
	public ResponseData<MemberInfoModel> getMemberFriendsWithMultiKeyWord(
			@RequestBody MemberFriendsKeyQueryVo memberFriendsKeyQueryVo);



	@RequestMapping(value = "/api/wxMembersApi/getMemberCodeByStoreCode",method = RequestMethod.POST)
	public ResponseData<List<String>> getMemberCodeByStoreCode(@RequestParam("brandId") Long brandId,@RequestParam("companyId") Long companyId,@RequestParam("storeCode") String storeCode);

}
